package com.outbrain.compose

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.rememberLazyListState
import androidx.compose.material.MaterialTheme
import androidx.compose.material.Surface
import androidx.compose.material.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.remember
import androidx.compose.ui.Modifier
import androidx.compose.ui.geometry.Offset
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.input.nestedscroll.NestedScrollConnection
import androidx.compose.ui.input.nestedscroll.NestedScrollSource
import androidx.compose.ui.input.nestedscroll.nestedScroll
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.viewinterop.AndroidView
import com.outbrain.OBSDK.Compose.OBComposeWidget
import com.outbrain.OBSDK.Outbrain
import com.outbrain.OBSDK.SFWebView.OutbrainBusProvider
import com.outbrain.compose.theme.ComposeListTheme
import com.squareup.otto.Subscribe

class MainActivity : ComponentActivity() {

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        Outbrain.register(this, "AndroidSampleApp2014")

        setContent {
            ComposeListTheme {
                MainScreen()
            }
        }
    }
}

@Composable
fun MainScreen() {
    // A surface container using the 'background' color from the theme
    Surface(
        modifier = Modifier.fillMaxSize(),
        color = MaterialTheme.colors.background
    ) {
        Column {
            SimpleView()
            ArticleContents()
        }
    }
}

@Composable
fun SimpleView() {
    Surface(
        modifier = Modifier
            .height(50.dp)
            .fillMaxWidth(),
        color = Color.Blue
    ) {

    }
}

@Composable
fun ArticleContents() {
    val context = LocalContext.current
    val listState = rememberLazyListState()

    val regularWidget = remember {
        OBComposeWidget(
            context = context,
            url = context.getString(R.string.outbrain_sample_url),
            widgetID = "MB_2",
            installationKey = "NANOWDGT01",
            itemIndex = 7,
            listState = listState
        )
    }

    val sfWidget = remember {
        OBComposeWidget(
            context = context,
            url = context.getString(R.string.outbrain_sample_url),
            widgetID = "MB_1",
            installationKey = "NANOWDGT01",
            itemIndex = 13,
            listState = listState
        )
    }

    val nestedScrollConnection = remember {
        object : NestedScrollConnection {
            override fun onPreScroll(available: Offset, source: NestedScrollSource): Offset {
                regularWidget.onScroll()
                sfWidget.onScroll()
                return Offset.Zero
            }
        }
    }

    LazyColumn(
        state = listState,
        modifier = Modifier
            .fillMaxHeight()
            .nestedScroll(nestedScrollConnection)
            .padding(top = 8.dp)
    )
    {
        item { ArticleContent(text = "Header") }
        item { ArticleContent(text = "Image") }
        item { ArticleContent(text = "Paragraph") }
        item { ArticleContent(text = "Paragraph") }
        item { ArticleContent(text = "Image") }
        item { ArticleContent(text = "Subheading") }
        item { ArticleContent(text = "Liveticker") }
        item { // Outbrain widget
            AndroidView(
                factory = { regularWidget },
                modifier = Modifier.fillMaxWidth()
            )
        }
        item { ArticleContent(text = "Image") }
        item { ArticleContent(text = "Paragraph") }
        item { ArticleContent(text = "Paragraph") }
        item { ArticleContent(text = "Image") }
        item { ArticleContent(text = "Footer") }
        item { // Outbrain widget
            AndroidView(
                factory = { sfWidget },
                modifier = Modifier.fillMaxWidth()
            )
        }
    }
}

@Composable
fun ArticleContent(modifier: Modifier = Modifier, text: String) {

    Text(
        modifier = modifier
            .height(100.dp)
            .fillMaxWidth()
            .padding(start = 8.dp, end = 8.dp, bottom = 8.dp),
        text = text
    )
}